# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponsePlotFile(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'caption': 'str',
        'dest_path': 'str',
        'file': 'StorageFile',
        'file_type': 'str',
        'step': 'int'
    }

    attribute_map = {
        'caption': 'caption',
        'dest_path': 'dest_path',
        'file': 'file',
        'file_type': 'file_type',
        'step': 'step'
    }

    def __init__(self, caption=None, dest_path=None, file=None, file_type=None, step=None, local_vars_configuration=None):  # noqa: E501
        """ResponsePlotFile - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._caption = None
        self._dest_path = None
        self._file = None
        self._file_type = None
        self._step = None
        self.discriminator = None

        if caption is not None:
            self.caption = caption
        if dest_path is not None:
            self.dest_path = dest_path
        if file is not None:
            self.file = file
        if file_type is not None:
            self.file_type = file_type
        self.step = step

    @property
    def caption(self):
        """Gets the caption of this ResponsePlotFile.  # noqa: E501


        :return: The caption of this ResponsePlotFile.  # noqa: E501
        :rtype: str
        """
        return self._caption

    @caption.setter
    def caption(self, caption):
        """Sets the caption of this ResponsePlotFile.


        :param caption: The caption of this ResponsePlotFile.  # noqa: E501
        :type caption: str
        """

        self._caption = caption

    @property
    def dest_path(self):
        """Gets the dest_path of this ResponsePlotFile.  # noqa: E501


        :return: The dest_path of this ResponsePlotFile.  # noqa: E501
        :rtype: str
        """
        return self._dest_path

    @dest_path.setter
    def dest_path(self, dest_path):
        """Sets the dest_path of this ResponsePlotFile.


        :param dest_path: The dest_path of this ResponsePlotFile.  # noqa: E501
        :type dest_path: str
        """

        self._dest_path = dest_path

    @property
    def file(self):
        """Gets the file of this ResponsePlotFile.  # noqa: E501


        :return: The file of this ResponsePlotFile.  # noqa: E501
        :rtype: StorageFile
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this ResponsePlotFile.


        :param file: The file of this ResponsePlotFile.  # noqa: E501
        :type file: StorageFile
        """

        self._file = file

    @property
    def file_type(self):
        """Gets the file_type of this ResponsePlotFile.  # noqa: E501


        :return: The file_type of this ResponsePlotFile.  # noqa: E501
        :rtype: str
        """
        return self._file_type

    @file_type.setter
    def file_type(self, file_type):
        """Sets the file_type of this ResponsePlotFile.


        :param file_type: The file_type of this ResponsePlotFile.  # noqa: E501
        :type file_type: str
        """
        allowed_values = ["image", "audio"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and file_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `file_type` ({0}), must be one of {1}"  # noqa: E501
                .format(file_type, allowed_values)
            )

        self._file_type = file_type

    @property
    def step(self):
        """Gets the step of this ResponsePlotFile.  # noqa: E501


        :return: The step of this ResponsePlotFile.  # noqa: E501
        :rtype: int
        """
        return self._step

    @step.setter
    def step(self, step):
        """Sets the step of this ResponsePlotFile.


        :param step: The step of this ResponsePlotFile.  # noqa: E501
        :type step: int
        """

        self._step = step

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponsePlotFile):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponsePlotFile):
            return True

        return self.to_dict() != other.to_dict()
